﻿using System;
using System.Collections.Generic;
using System.Drawing;
using System.Reflection;

using DevExpress.XtraEditors;
using DevExpress.XtraMap;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : XtraForm
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 가로/높이 비율 리스트
        /// </summary>
        private List<WidthHeightRatio> widthHeightRatioList = new List<WidthHeightRatio>()
        {
            new WidthHeightRatio() { Name = "Default"        , Value = 1    },
            new WidthHeightRatio() { Name = "Lambert"        , Value = 3.14 },
            new WidthHeightRatio() { Name = "Behrmann"       , Value = 2.36 },
            new WidthHeightRatio() { Name = "Trystan Edwards", Value = 2    },
            new WidthHeightRatio() { Name = "Gall-Peters"    , Value = 1.57 },
            new WidthHeightRatio() { Name = "Balthasart"     , Value = 1.3  }
        };

        /// <summary>
        /// 디폴트 사이드 크기
        /// </summary>
        private const int DEFAULT_SIDE_SIZE = 512;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            Load                                        += Form_Load;
            this.ratioComboBoxEdit.SelectedIndexChanged += ratioComboBoxEdit_SelectedIndexChanged;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 폼 로드시 처리하기 - Form_Load(sender, e)

        /// <summary>
        /// 폼 로드시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void Form_Load(object sender, EventArgs e)
        {
            this.ratioComboBoxEdit.Properties.Items.AddRange(this.widthHeightRatioList);

            this.ratioComboBoxEdit.SelectedIndex = 0;

            Uri baseURI = new Uri(Assembly.GetEntryAssembly().Location);

            Uri uri = new Uri(baseURI, "DATA/Countries.shp");

            this.mapControl.Layers.Add
            (
                new VectorItemsLayer()
                {
                    Data = new ShapefileDataAdapter() { FileUri = uri }
                }
            );
        }

        #endregion
        #region 비율 콤보 박스 에디터 선택 인덱스 변경시 처리하기 - ratioComboBoxEdit_SelectedIndexChanged(sender, e)

        /// <summary>
        /// 비율 콤보 박스 에디터 선택 인덱스 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void ratioComboBoxEdit_SelectedIndexChanged(object sender, EventArgs e)
        {
            this.mapControl.InitialMapSize = new Size()
            {
                Width  = DEFAULT_SIDE_SIZE,
                Height = (int)(DEFAULT_SIDE_SIZE / ((WidthHeightRatio)this.ratioComboBoxEdit.SelectedItem).Value)
            };
        }

        #endregion
    }
}